from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class IntRes2d_SequenceOfIntersectionPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntRes2d_IntersectionPoint: ...
    def Last(self) -> IntRes2d_IntersectionPoint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntRes2d_IntersectionPoint) -> IntRes2d_IntersectionPoint: ...
    def Prepend(self, theItem: IntRes2d_IntersectionPoint) -> IntRes2d_IntersectionPoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntRes2d_IntersectionPoint: ...
    def SetValue(self, theIndex: int, theValue: IntRes2d_IntersectionPoint) -> None: ...

class IntRes2d_SequenceOfIntersectionSegment:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntRes2d_IntersectionSegment: ...
    def Last(self) -> IntRes2d_IntersectionSegment: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntRes2d_IntersectionSegment) -> IntRes2d_IntersectionSegment: ...
    def Prepend(self, theItem: IntRes2d_IntersectionSegment) -> IntRes2d_IntersectionSegment: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntRes2d_IntersectionSegment: ...
    def SetValue(self, theIndex: int, theValue: IntRes2d_IntersectionSegment) -> None: ...

class IntRes2d_Position(IntEnum):
	IntRes2d_Head: int = ...
	IntRes2d_Middle: int = ...
	IntRes2d_End: int = ...
IntRes2d_Head = IntRes2d_Position.IntRes2d_Head
IntRes2d_Middle = IntRes2d_Position.IntRes2d_Middle
IntRes2d_End = IntRes2d_Position.IntRes2d_End

class IntRes2d_Situation(IntEnum):
	IntRes2d_Inside: int = ...
	IntRes2d_Outside: int = ...
	IntRes2d_Unknown: int = ...
IntRes2d_Inside = IntRes2d_Situation.IntRes2d_Inside
IntRes2d_Outside = IntRes2d_Situation.IntRes2d_Outside
IntRes2d_Unknown = IntRes2d_Situation.IntRes2d_Unknown

class IntRes2d_TypeTrans(IntEnum):
	IntRes2d_In: int = ...
	IntRes2d_Out: int = ...
	IntRes2d_Touch: int = ...
	IntRes2d_Undecided: int = ...
IntRes2d_In = IntRes2d_TypeTrans.IntRes2d_In
IntRes2d_Out = IntRes2d_TypeTrans.IntRes2d_Out
IntRes2d_Touch = IntRes2d_TypeTrans.IntRes2d_Touch
IntRes2d_Undecided = IntRes2d_TypeTrans.IntRes2d_Undecided

class IntRes2d_Domain:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Pnt1: gp_Pnt2d, Par1: float, Tol1: float, Pnt2: gp_Pnt2d, Par2: float, Tol2: float) -> None: ...
	@overload
	def __init__(self, Pnt: gp_Pnt2d, Par: float, Tol: float, First: bool) -> None: ...
	def EquivalentParameters(self) -> Tuple[float, float]: ...
	def FirstParameter(self) -> float: ...
	def FirstPoint(self) -> gp_Pnt2d: ...
	def FirstTolerance(self) -> float: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def IsClosed(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def LastPoint(self) -> gp_Pnt2d: ...
	def LastTolerance(self) -> float: ...
	def SetEquivalentParameters(self, zero: float, period: float) -> None: ...
	@overload
	def SetValues(self, Pnt1: gp_Pnt2d, Par1: float, Tol1: float, Pnt2: gp_Pnt2d, Par2: float, Tol2: float) -> None: ...
	@overload
	def SetValues(self) -> None: ...
	@overload
	def SetValues(self, Pnt: gp_Pnt2d, Par: float, Tol: float, First: bool) -> None: ...

class IntRes2d_Intersection:
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def Point(self, N: int) -> IntRes2d_IntersectionPoint: ...
	def Segment(self, N: int) -> IntRes2d_IntersectionSegment: ...
	def SetReversedParameters(self, Reverseflag: bool) -> None: ...

class IntRes2d_IntersectionPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, Uc1: float, Uc2: float, Trans1: IntRes2d_Transition, Trans2: IntRes2d_Transition, ReversedFlag: bool) -> None: ...
	def ParamOnFirst(self) -> float: ...
	def ParamOnSecond(self) -> float: ...
	def SetValues(self, P: gp_Pnt2d, Uc1: float, Uc2: float, Trans1: IntRes2d_Transition, Trans2: IntRes2d_Transition, ReversedFlag: bool) -> None: ...
	def TransitionOfFirst(self) -> IntRes2d_Transition: ...
	def TransitionOfSecond(self) -> IntRes2d_Transition: ...
	def Value(self) -> gp_Pnt2d: ...

class IntRes2d_IntersectionSegment:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: IntRes2d_IntersectionPoint, P2: IntRes2d_IntersectionPoint, Oppos: bool, ReverseFlag: bool) -> None: ...
	@overload
	def __init__(self, P: IntRes2d_IntersectionPoint, First: bool, Oppos: bool, ReverseFlag: bool) -> None: ...
	@overload
	def __init__(self, Oppos: bool) -> None: ...
	def FirstPoint(self) -> IntRes2d_IntersectionPoint: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def IsOpposite(self) -> bool: ...
	def LastPoint(self) -> IntRes2d_IntersectionPoint: ...

class IntRes2d_Transition:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Tangent: bool, Pos: IntRes2d_Position, Type: IntRes2d_TypeTrans) -> None: ...
	@overload
	def __init__(self, Tangent: bool, Pos: IntRes2d_Position, Situ: IntRes2d_Situation, Oppos: bool) -> None: ...
	@overload
	def __init__(self, Pos: IntRes2d_Position) -> None: ...
	def IsOpposite(self) -> bool: ...
	def IsTangent(self) -> bool: ...
	def PositionOnCurve(self) -> IntRes2d_Position: ...
	def SetPosition(self, Pos: IntRes2d_Position) -> None: ...
	@overload
	def SetValue(self, Tangent: bool, Pos: IntRes2d_Position, Type: IntRes2d_TypeTrans) -> None: ...
	@overload
	def SetValue(self, Tangent: bool, Pos: IntRes2d_Position, Situ: IntRes2d_Situation, Oppos: bool) -> None: ...
	@overload
	def SetValue(self, Pos: IntRes2d_Position) -> None: ...
	def Situation(self) -> IntRes2d_Situation: ...
	def TransitionType(self) -> IntRes2d_TypeTrans: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Message import *
from OCC.Core.BinMDF import *
from OCC.Core.TDocStd import *
from OCC.Core.TCollection import *
from OCC.Core.BinLDrivers import *
from OCC.Core.Storage import *


class BinDrivers_Marker(IntEnum):
	BinDrivers_ENDATTRLIST: int = ...
	BinDrivers_ENDLABEL: int = ...
BinDrivers_ENDATTRLIST = BinDrivers_Marker.BinDrivers_ENDATTRLIST
BinDrivers_ENDLABEL = BinDrivers_Marker.BinDrivers_ENDLABEL

class bindrivers:
	@staticmethod
	def AttributeDrivers(MsgDrv: Message_Messenger) -> BinMDF_ADriverTable: ...
	@staticmethod
	def DefineFormat(theApp: TDocStd_Application) -> None: ...
	@staticmethod
	def Factory(theGUID: Standard_GUID) -> Standard_Transient: ...
	@staticmethod
	def StorageVersion() -> TCollection_AsciiString: ...

class BinDrivers_DocumentRetrievalDriver(BinLDrivers_DocumentRetrievalDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> BinMDF_ADriverTable: ...
	def Clear(self) -> None: ...

class BinDrivers_DocumentStorageDriver(BinLDrivers_DocumentStorageDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> BinMDF_ADriverTable: ...
	def IsWithTriangles(self) -> bool: ...
	def SetWithTriangles(self, theMessageDriver: Message_Messenger, theWithTriangulation: bool) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

bindrivers_AttributeDrivers = bindrivers.AttributeDrivers
bindrivers_DefineFormat = bindrivers.DefineFormat
bindrivers_Factory = bindrivers.Factory
bindrivers_StorageVersion = bindrivers.StorageVersion



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Message import *
from OCC.Core.XmlMDF import *
from OCC.Core.TCollection import *
from OCC.Core.TDocStd import *
from OCC.Core.PCDM import *
from OCC.Core.CDM import *
from OCC.Core.Storage import *


class XmlLDrivers_SequenceOfNamespaceDef:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> XmlLDrivers_NamespaceDef: ...
    def Last(self) -> XmlLDrivers_NamespaceDef: ...
    def Length(self) -> int: ...
    def Append(self, theItem: XmlLDrivers_NamespaceDef) -> XmlLDrivers_NamespaceDef: ...
    def Prepend(self, theItem: XmlLDrivers_NamespaceDef) -> XmlLDrivers_NamespaceDef: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> XmlLDrivers_NamespaceDef: ...
    def SetValue(self, theIndex: int, theValue: XmlLDrivers_NamespaceDef) -> None: ...

class xmlldrivers:
	@staticmethod
	def AttributeDrivers(theMsgDriver: Message_Messenger) -> XmlMDF_ADriverTable: ...
	@staticmethod
	def CreationDate() -> TCollection_AsciiString: ...
	@staticmethod
	def DefineFormat(theApp: TDocStd_Application) -> None: ...
	@staticmethod
	def Factory(theGUID: Standard_GUID) -> Standard_Transient: ...
	@staticmethod
	def StorageVersion() -> int: ...

class XmlLDrivers_DocumentRetrievalDriver(PCDM_RetrievalDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> XmlMDF_ADriverTable: ...
	def CreateDocument(self) -> CDM_Document: ...
	@overload
	def Read(self, theFileName: TCollection_ExtendedString, theNewDocument: CDM_Document, theApplication: CDM_Application, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...

class XmlLDrivers_DocumentStorageDriver(PCDM_StorageDriver):
	def __init__(self, theCopyright: TCollection_ExtendedString) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> XmlMDF_ADriverTable: ...
	@overload
	def Write(self, theDocument: CDM_Document, theFileName: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...

class XmlLDrivers_NamespaceDef:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePrefix: TCollection_AsciiString, theURI: TCollection_AsciiString) -> None: ...
	def Prefix(self) -> TCollection_AsciiString: ...
	def URI(self) -> TCollection_AsciiString: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlldrivers_AttributeDrivers = xmlldrivers.AttributeDrivers
xmlldrivers_CreationDate = xmlldrivers.CreationDate
xmlldrivers_DefineFormat = xmlldrivers.DefineFormat
xmlldrivers_Factory = xmlldrivers.Factory
xmlldrivers_StorageVersion = xmlldrivers.StorageVersion



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.gp import *


class LProp3d_CLProps:
	@overload
	def __init__(self, C: Adaptor3d_HCurve, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve, U: float, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, N: int, Resolution: float) -> None: ...
	def CentreOfCurvature(self, P: gp_Pnt) -> None: ...
	def Curvature(self) -> float: ...
	def D1(self) -> gp_Vec: ...
	def D2(self) -> gp_Vec: ...
	def D3(self) -> gp_Vec: ...
	def IsTangentDefined(self) -> bool: ...
	def Normal(self, N: gp_Dir) -> None: ...
	def SetCurve(self, C: Adaptor3d_HCurve) -> None: ...
	def SetParameter(self, U: float) -> None: ...
	def Tangent(self, D: gp_Dir) -> None: ...
	def Value(self) -> gp_Pnt: ...

class LProp3d_CurveTool:
	@staticmethod
	def Continuity(C: Adaptor3d_HCurve) -> int: ...
	@staticmethod
	def D1(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@staticmethod
	def D2(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@staticmethod
	def D3(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@staticmethod
	def FirstParameter(C: Adaptor3d_HCurve) -> float: ...
	@staticmethod
	def LastParameter(C: Adaptor3d_HCurve) -> float: ...
	@staticmethod
	def Value(C: Adaptor3d_HCurve, U: float, P: gp_Pnt) -> None: ...

class LProp3d_SLProps:
	@overload
	def __init__(self, S: Adaptor3d_HSurface, U: float, V: float, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, N: int, Resolution: float) -> None: ...
	def CurvatureDirections(self, MaxD: gp_Dir, MinD: gp_Dir) -> None: ...
	def D1U(self) -> gp_Vec: ...
	def D1V(self) -> gp_Vec: ...
	def D2U(self) -> gp_Vec: ...
	def D2V(self) -> gp_Vec: ...
	def DUV(self) -> gp_Vec: ...
	def GaussianCurvature(self) -> float: ...
	def IsCurvatureDefined(self) -> bool: ...
	def IsNormalDefined(self) -> bool: ...
	def IsTangentUDefined(self) -> bool: ...
	def IsTangentVDefined(self) -> bool: ...
	def IsUmbilic(self) -> bool: ...
	def MaxCurvature(self) -> float: ...
	def MeanCurvature(self) -> float: ...
	def MinCurvature(self) -> float: ...
	def Normal(self) -> gp_Dir: ...
	def SetParameters(self, U: float, V: float) -> None: ...
	def SetSurface(self, S: Adaptor3d_HSurface) -> None: ...
	def TangentU(self, D: gp_Dir) -> None: ...
	def TangentV(self, D: gp_Dir) -> None: ...
	def Value(self) -> gp_Pnt: ...

class LProp3d_SurfaceTool:
	@staticmethod
	def Bounds(S: Adaptor3d_HSurface) -> Tuple[float, float, float, float]: ...
	@staticmethod
	def Continuity(S: Adaptor3d_HSurface) -> int: ...
	@staticmethod
	def D1(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	@staticmethod
	def D2(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, DUV: gp_Vec) -> None: ...
	@staticmethod
	def DN(S: Adaptor3d_HSurface, U: float, V: float, IU: int, IV: int) -> gp_Vec: ...
	@staticmethod
	def Value(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

LProp3d_CurveTool_Continuity = LProp3d_CurveTool.Continuity
LProp3d_CurveTool_D1 = LProp3d_CurveTool.D1
LProp3d_CurveTool_D2 = LProp3d_CurveTool.D2
LProp3d_CurveTool_D3 = LProp3d_CurveTool.D3
LProp3d_CurveTool_FirstParameter = LProp3d_CurveTool.FirstParameter
LProp3d_CurveTool_LastParameter = LProp3d_CurveTool.LastParameter
LProp3d_CurveTool_Value = LProp3d_CurveTool.Value
LProp3d_SurfaceTool_Bounds = LProp3d_SurfaceTool.Bounds
LProp3d_SurfaceTool_Continuity = LProp3d_SurfaceTool.Continuity
LProp3d_SurfaceTool_D1 = LProp3d_SurfaceTool.D1
LProp3d_SurfaceTool_D2 = LProp3d_SurfaceTool.D2
LProp3d_SurfaceTool_DN = LProp3d_SurfaceTool.DN
LProp3d_SurfaceTool_Value = LProp3d_SurfaceTool.Value
